@@ -15,7 +15,7 @@
 /* #undef BUILD_GLES2 */
 #endif
 
-// COLOR flags
+// Miscellaneous flags
 
 #ifndef COLOR_16_BIT
 /* #undef COLOR_16_BIT */
@@ -25,6 +25,14 @@
 /* #undef COLOR_5_6_5 */
 #endif
 
+#ifndef DISABLE_THREADING
+/* #undef DISABLE_THREADING */
+#endif
+
+#ifndef FIXED_ROM_BUFFER
+/* #undef FIXED_ROM_BUFFER */
+#endif
+
 // M_CORE flags
 
 #ifndef M_CORE_GBA
@@ -35,9 +43,13 @@
 #define M_CORE_GB
 #endif
 
-// USE flags
+// ENABLE flags
 
-#ifndef MINIMAL_CORE
+#ifndef ENABLE_SCRIPTING
+#define ENABLE_SCRIPTING
+#endif
+
+// USE flags
 
 #ifndef USE_DEBUGGERS
 #define USE_DEBUGGERS
@@ -47,12 +59,16 @@
 #define USE_EDITLINE
 #endif
 
+#ifndef USE_ELF
+#define USE_ELF
+#endif
+
 #ifndef USE_EPOXY
 /* #undef USE_EPOXY */
 #endif
 
 #ifndef USE_FFMPEG
-/* #undef USE_FFMPEG */
+#define USE_FFMPEG
 #endif
 
 #ifndef USE_GDB_STUB
@@ -63,6 +79,14 @@
 /* #undef USE_LIBAV */
 #endif
 
+#ifndef USE_LIBAVRESAMPLE
+/* #undef USE_LIBAVRESAMPLE */
+#endif
+
+#ifndef USE_LIBSWRESAMPLE
+#define USE_LIBSWRESAMPLE
+#endif
+
 #ifndef USE_LIBZIP
 #define USE_LIBZIP
 #endif
@@ -96,5 +120,3 @@
 #endif
 
 #endif
-
-#endif
